Documentation
=============

From the root of the repo, to build the documentation run::

   > ./run.sh docs

If you want to build from fresh then say::

   > ./run.sh docs fresh

Once your documentation is built do something like::

   > ./run.sh docs view
